update_input_buffer

Function update_input_buffer 

pub fn update_input_buffer(
    key: KeyEvent,
    buffer: &str,
    cursor: usize,
) -> Option<(String, usize)>
Update input buffer based on key event Returns the new buffer content, or None if no change