Mouse and keyboard input handling for file operations
Structs
- Click
Detector - Detects double-clicks by tracking click timing
- Path
Buffer - Buffers rapid keyboard input to detect file paths from drag-and-drop
Enums
- Mouse
Action - Actions triggered by mouse events
Functions
- handle_
mouse_ event - Process a mouse event and return the resulting action