pub struct LayoutEngine {
pub width: u16,
pub height: u16,
pub density: UiDensity,
}Expand description
Main layout engine
Fields
width: u16Terminal width
height: u16Terminal height
density: UiDensityCurrent UI density
Implementations
Sourceimpl LayoutEngine
impl LayoutEngine
Sourcepub fn new(width: u16, height: u16) -> Self
pub fn new(width: u16, height: u16) -> Self
Create a new layout engine from terminal dimensions
Sourcepub fn new_with_density(width: u16, height: u16, density: UiDensity) -> Self
pub fn new_with_density(width: u16, height: u16, density: UiDensity) -> Self
Create a new layout engine with an explicit density override
Sourcepub fn from_rect_with_density(area: Rect, density: UiDensity) -> Self
pub fn from_rect_with_density(area: Rect, density: UiDensity) -> Self
Create from a Rect with explicit density
Sourcepub fn tree_columns(&self, area: Rect) -> TreeColumns
pub fn tree_columns(&self, area: Rect) -> TreeColumns
Get tree column configuration
Sourcepub fn status_layout(&self) -> StatusLayout
pub fn status_layout(&self) -> StatusLayout
Get status layout configuration
Sourcepub fn should_show_icons(&self) -> bool
pub fn should_show_icons(&self) -> bool
Check if icons should be shown
Sourcepub fn max_filename_width(&self, area: Rect) -> usize
pub fn max_filename_width(&self, area: Rect) -> usize
Get maximum filename width for tree display
Sourcepub fn peek_preview_lines(&self) -> usize
pub fn peek_preview_lines(&self) -> usize
Get peek preview line count
Sourcepub fn split_ratio(&self, preview_visible: bool) -> (u16, u16)
pub fn split_ratio(&self, preview_visible: bool) -> (u16, u16)
Calculate tree/preview split ratio
Returns (tree_percentage, preview_percentage)
Sourcepub fn should_show_preview(&self, preview_enabled: bool) -> bool
pub fn should_show_preview(&self, preview_enabled: bool) -> bool
Check if preview should be visible given current settings
Sourcepub fn help_popup_size(&self) -> (u16, u16)
pub fn help_popup_size(&self) -> (u16, u16)
Get help popup dimensions
Sourcepub fn title_max_len(&self, area: Rect) -> usize
pub fn title_max_len(&self, area: Rect) -> usize
Get title max length for tree panel