Module preview

Module preview 

Preview rendering (text, images, and directory info)

Structs

DirectoryInfo
Directory information for preview
HexPreview
Hex preview content for binary files
ImagePreview
Image preview data (RGB pixels)
TextPreview
Text preview content

Functions

is_binary_file
Check if a file is likely a binary file (not text, not image)
is_image_file
Check if a file is likely an image
is_text_file
Check if a file is likely a text file
render_directory_info
Render directory info preview
render_hex_preview
Render hex preview (xxd-style)
render_image_preview
Render image preview using half-block characters
render_text_preview
Render text preview