Preview rendering (text, images, and directory info)
Structs
- Directory
Info - Directory information for preview
- HexPreview
- Hex preview content for binary files
- Image
Preview - Image preview data (RGB pixels)
- Text
Preview - Text preview content
Functions
- is_
binary_ file - Check if a file is likely a binary file (not text, not image)
- is_
image_ file - Check if a file is likely an image
- is_
text_ file - Check if a file is likely a text file
- render_
directory_ info - Render directory info preview
- render_
hex_ preview - Render hex preview (xxd-style)
- render_
image_ preview - Render image preview using half-block characters
- render_
text_ preview - Render text preview